AlignmentExporter

Trait AlignmentExporter 

pub trait AlignmentExporter {
    // Required method
    fn get_alignment() -> &'static [Alignment];
}
Any type that uses the procedural macro automatically has this trait implemented for it. Use AlignmentExporter::get_alignment to get the alignment information of a struct.

Required Methods

fn get_alignment() -> &'static [Alignment]

Get the alignment of a struct.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors